============
Python Tyuio
============

Tyuio is a Simple Event Dispatcher api.

**Project page:** https://github.com/moisespsena/py_tyuio

**Documentation page:** https://pythonhosted.org/tyuio

**********
INSTALL IT
**********

Install it using **pip** or **easy_install**::

    pip install tyuio

or::

    easy_install tyuio
